[PATCH 3 of 3] model: trivial typo fixes
Thomas De Schampheleire
patrickdepinguin at gmail.com
Thu Mar 12 17:21:50 EDT 2015
# HG changeset patch
# User Thomas De Schampheleire <thomas.de.schampheleire at gmail.com>
# Date 1426194420 -3600
# Thu Mar 12 22:07:00 2015 +0100
# Node ID 475baaa473eb3ea0f4efe567cab0822f372f3b97
# Parent cf7a42169bc6ea366ca64a647b69dc5c2667df08
model: trivial typo fixes
diff --git a/kallithea/model/changeset_status.py b/kallithea/model/changeset_status.py
--- a/kallithea/model/changeset_status.py
+++ b/kallithea/model/changeset_status.py
@@ -3,7 +3,7 @@
kallithea.model.changeset_status
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-Changeset status conttroller
+Changeset status controller
This file was forked by the Kallithea project in July 2014.
Original author and date, and relevant copyright and licensing information is below:
diff --git a/kallithea/model/db.py b/kallithea/model/db.py
--- a/kallithea/model/db.py
+++ b/kallithea/model/db.py
@@ -69,7 +69,7 @@
class BaseModel(object):
"""
- Base Model for all classess
+ Base Model for all classes
"""
@classmethod
@@ -97,7 +97,7 @@
return d
def get_appstruct(self):
- """return list with keys and values tupples corresponding
+ """return list with keys and values tuples corresponding
to this model data """
l = []
@@ -1051,7 +1051,7 @@
def normalize_repo_name(cls, repo_name):
"""
Normalizes os specific repo_name to the format internally stored inside
- dabatabase using URL_SEP
+ database using URL_SEP
:param cls:
:param repo_name:
@@ -1540,7 +1540,7 @@
if gr is None:
break
if cnt == parents_recursion_limit:
- # this will prevent accidental infinit loops
+ # this will prevent accidental infinite loops
log.error(('more than %s parents found for group %s, stopping '
'recursive parent fetching' % (parents_recursion_limit, self)))
break
diff --git a/kallithea/model/forms.py b/kallithea/model/forms.py
--- a/kallithea/model/forms.py
+++ b/kallithea/model/forms.py
@@ -12,9 +12,9 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
"""
-this is forms validation classes
+these are form validation classes
http://formencode.org/module-formencode.validators.html
-for list off all availible validators
+for list of all available validators
we can create our own validators
diff --git a/kallithea/model/user.py b/kallithea/model/user.py
--- a/kallithea/model/user.py
+++ b/kallithea/model/user.py
@@ -335,7 +335,7 @@
"""
Fetches auth_user by user_id,or api_key if present.
Fills auth_user attributes with those taken from database.
- Additionally sets is_authenitated if lookup fails
+ Additionally sets is_authenticated if lookup fails
present in database
:param auth_user: instance of user to set attributes
diff --git a/kallithea/model/validators.py b/kallithea/model/validators.py
--- a/kallithea/model/validators.py
+++ b/kallithea/model/validators.py
@@ -643,7 +643,7 @@
if member == User.DEFAULT_USER:
if str2bool(value.get('repo_private')):
# set none for default when updating to
- # private repo protects agains form manipulation
+ # private repo protects against form manipulation
v = EMPTY_PERM
perms_update.add((member, v, t))
More information about the kallithea-general
mailing list
diff --git a/kallithea/model/scm.py b/kallithea/model/scm.py
--- a/kallithea/model/scm.py
+++ b/kallithea/model/scm.py
@@ -475,7 +475,7 @@
:param repo: SCM repo
:param username: username who pushes
- :param action: push/push_loca/push_remote
+ :param action: push/push_local/push_remote
:param repo_name: name of repo
:param revisions: list of revisions that we pushed
"""
@@ -611,15 +611,15 @@
"""
Commits specified nodes to repo.
:param user: Kallithea User object or user_id, the commiter
:param repo: Kallithea Repository object
:param message: commit message
:param nodes: mapping {filename:{'content':content},...}
:param parent_cs: parent changeset, can be empty than it's initial commit
:param author: author of commit, cna be different that commiter only for git
:param trigger_push_hook: trigger push hooks
- :returns: new commited changeset
+ :returns: new committed changeset
"""
user = self._get_user(user)
@@ -643,8 +643,8 @@
processed_nodes.append((f_path, content))
message = safe_unicode(message)
- commiter = user.full_contact
- author = safe_unicode(author) if author else commiter
+ committer = user.full_contact
+ author = safe_unicode(author) if author else committer
IMC = self._get_IMC_module(scm_instance.alias)
imc = IMC(scm_instance)
@@ -681,8 +681,8 @@
scm_instance = repo.scm_instance_no_cache()
message = safe_unicode(message)
- commiter = user.full_contact
- author = safe_unicode(author) if author else commiter
+ committer = user.full_contact
+ author = safe_unicode(author) if author else committer
imc_class = self._get_IMC_module(scm_instance.alias)
imc = imc_class(scm_instance)
@@ -736,15 +736,15 @@
"""
Deletes specified nodes from repo.
:param user: Kallithea User object or user_id, the commiter
:param repo: Kallithea Repository object
:param message: commit message
:param nodes: mapping {filename:{'content':content},...}
:param parent_cs: parent changeset, can be empty than it's initial commit
:param author: author of commit, cna be different that commiter only for git
:param trigger_push_hook: trigger push hooks
- :returns: new commited changeset after deletion
+ :returns: new committed changeset after deletion
"""
user = self._get_user(user)
@@ -759,8 +759,8 @@
processed_nodes.append((f_path, content))
message = safe_unicode(message)
- commiter = user.full_contact
- author = safe_unicode(author) if author else commiter
+ committer = user.full_contact
+ author = safe_unicode(author) if author else committer
IMC = self._get_IMC_module(scm_instance.alias)
imc = IMC(scm_instance)
@@ -611,15 +611,15 @@
"""
Commits specified nodes to repo.
- :param user: Kallithea User object or user_id, the commiter
+ :param user: Kallithea User object or user_id, the committer
:param repo: Kallithea Repository object
:param message: commit message
@@ -611,15 +611,15 @@
:param nodes: mapping {filename:{'content':content},...}
:param parent_cs: parent changeset, can be empty than it's initial commit
- :param author: author of commit, cna be different that commiter only for git
+ :param author: author of commit, cna be different that committer only for git
:param trigger_push_hook: trigger push hooks
@@ -736,15 +736,15 @@
"""
Deletes specified nodes from repo.
- :param user: Kallithea User object or user_id, the commiter
+ :param user: Kallithea User object or user_id, the committer
:param repo: Kallithea Repository object
:param message: commit message
@@ -736,15 +736,15 @@
:param nodes: mapping {filename:{'content':content},...}
:param parent_cs: parent changeset, can be empty than it's initial commit
- :param author: author of commit, cna be different that commiter only for git
+ :param author: author of commit, cna be different that committer only for git
:param trigger_push_hook: trigger push hooks